from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SeMask:
	"""SeMask commands group definition. 13 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("seMask", core, parent)

	@property
	def obwLimit(self):
		"""obwLimit commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_obwLimit'):
			from .SeMask_.ObwLimit import ObwLimit
			self._obwLimit = ObwLimit(self._core, self._base)
		return self._obwLimit

	@property
	def limit(self):
		"""limit commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_limit'):
			from .SeMask_.Limit import Limit
			self._limit = Limit(self._core, self._base)
		return self._limit

	@property
	def atTolerance(self):
		"""atTolerance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_atTolerance'):
			from .SeMask_.AtTolerance import AtTolerance
			self._atTolerance = AtTolerance(self._core, self._base)
		return self._atTolerance

	def clone(self) -> 'SeMask':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SeMask(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
